@@ -30,6 +30,8 @@
 #include <math.h>
 
 #include "libs/fvwmlib.h"
+#include "libs/Parse.h"
+#include "libs/wild.h"
 #include "libs/FScreen.h"
 #include "libs/charmap.h"
 #include "libs/wcontext.h"
@@ -398,7 +400,7 @@ void FreeConditionMask(WindowConditionMask *mask)
 			p2=p->next;
 			if(!p2)
 			{
-				free(p->name - (pp->invert ? 1 : 0));
+				free(p->name);
 			}
 			free(p);
 			p=p2;
@@ -427,8 +429,9 @@ void DefaultConditionMask(WindowConditionMask *mask)
  */
 void CreateConditionMask(char *flags, WindowConditionMask *mask)
 {
+	char *allocated_condition;
+	char *next_condition;
 	char *condition;
-	char *prev_condition = NULL;
 	char *tmp;
 	unsigned int state;
 
@@ -438,8 +441,8 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 	}
 
 	/* Next parse the flags in the string. */
-	tmp = flags;
-	tmp = GetNextSimpleOption(tmp, &condition);
+	next_condition = GetNextFullOption(flags, &allocated_condition);
+	condition = PeekToken(allocated_condition, &tmp);
 
 	while (condition)
 	{
@@ -492,8 +495,7 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 			    (button >= 1 &&
 			     button <= NUMBER_OF_EXTENDED_MOUSE_BUTTONS))
 			{
-				free(condition);
-				tmp = GetNextToken (tmp, &condition);
+				tmp = SkipNTokens(tmp, 1);
 				button_mask = (1<<(button-1));
 			}
 			else
@@ -685,16 +687,14 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 					CLEAR_USER_STATES(mask, state);
 				}
 				SETM_USER_STATES(mask, state);
-				free(condition);
-				tmp = GetNextToken(tmp, &condition);
+				tmp = SkipNTokens(tmp, 1);
 			}
 		}
 		else if (StrEquals(condition, "Layer"))
 		{
 			if (sscanf(tmp, "%d", &mask->layer))
 			{
-				free(condition);
-				tmp = GetNextToken (tmp, &condition);
+				tmp = SkipNTokens(tmp, 1);
 				if (mask->layer < 0)
 				{
 					/* silently ignore invalid layers */
@@ -712,7 +712,7 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 		{
 			struct name_condition *pp;
 			struct namelist *p;
-			char *condp;
+			char *condp = safestrdup(cond);
 
 			pp = (struct name_condition *)
 				safemalloc(sizeof(struct name_condition));
@@ -720,7 +720,7 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 			pp->namelist = NULL;
 			pp->next = mask->name_condition;
 			mask->name_condition = pp;
-			for(condp=cond; ; )
+			for (;;)
 			{
 				p = (struct namelist *)
 					safemalloc(sizeof(struct namelist));
@@ -737,20 +737,29 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 				}
 				*condp++='\0';
 			}
-			condition = NULL;	/* so it won't be freed */
 		}
 
-		if (prev_condition)
+		if (tmp && *tmp)
 		{
-			free(prev_condition);
+			fvwm_msg(OLD, "CreateConditionMask",
+				 "Use comma instead of whitespace to "
+				 "separate conditions");
 		}
-
-		prev_condition = condition;
-		tmp = GetNextSimpleOption(tmp, &condition);
-	}
-	if (prev_condition)
-	{
-		free(prev_condition);
+		else
+		{
+			if (allocated_condition != NULL)
+			{
+				free(allocated_condition);
+				allocated_condition = NULL;
+			}
+			if (next_condition && *next_condition)
+			{
+				next_condition = GetNextFullOption(
+					next_condition, &allocated_condition);
+			}
+			tmp = allocated_condition;
+		}
+		condition = PeekToken(tmp, &tmp);
 	}
 
 	return;
@@ -778,65 +787,79 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 	   hints etc.) */
 	if (IS_SIZE_FIXED(mask) &&
 	    mask->flag_mask.common.s.is_size_fixed &&
-	    is_function_allowed(F_RESIZE,NULL,fw,True,False))
+	    is_function_allowed(F_RESIZE, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
 	if (!IS_SIZE_FIXED(mask) &&
 	    mask->flag_mask.common.s.is_size_fixed &&
-	    !is_function_allowed(F_RESIZE,NULL,fw,True,False))
+	    !is_function_allowed(F_RESIZE, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
 	if (IS_FIXED(mask) &&
 	    mask->flag_mask.common.s.is_fixed &&
-	    is_function_allowed(F_MOVE, NULL, fw, True, False))
+	    is_function_allowed(F_MOVE, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
 	if (!IS_FIXED(mask) &&
 	    mask->flag_mask.common.s.is_fixed &&
-	    !is_function_allowed(F_MOVE, NULL, fw, True, False))
+	    !is_function_allowed(F_MOVE, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
 	if (IS_UNICONIFIABLE(mask) &&
 	    mask->flag_mask.common.s.is_uniconifiable &&
-	    is_function_allowed(F_ICONIFY,NULL,fw,True,False))
+	    is_function_allowed(F_ICONIFY, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
-	if (!IS_UNICONIFIABLE(mask) &&
-	    mask->flag_mask.common.s.is_uniconifiable &&
-	    !is_function_allowed(F_ICONIFY,NULL,fw,True,False))
+	if (
+		!IS_UNICONIFIABLE(mask) &&
+		mask->flag_mask.common.s.is_uniconifiable &&
+		!is_function_allowed(
+			F_ICONIFY, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
-	if (IS_UNMAXIMIZABLE(mask) &&
-	    mask->flag_mask.common.s.is_unmaximizable &&
-	    is_function_allowed(F_MAXIMIZE,NULL,fw,True,False))
+	if (
+		IS_UNMAXIMIZABLE(mask) &&
+		mask->flag_mask.common.s.is_unmaximizable &&
+		is_function_allowed(
+			F_MAXIMIZE, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
-	if (!IS_UNMAXIMIZABLE(mask) &&
-	    mask->flag_mask.common.s.is_unmaximizable &&
-	    !is_function_allowed(F_MAXIMIZE,NULL,fw,True,False))
+	if (
+		!IS_UNMAXIMIZABLE(mask) &&
+		mask->flag_mask.common.s.is_unmaximizable &&
+		!is_function_allowed(
+			F_MAXIMIZE, NULL, fw, RQORIG_PROGRAM_US, False))
 	{
 	        return False;
 	}
-	if (IS_UNCLOSABLE(mask) &&
-	    mask->flag_mask.common.s.is_unclosable &&
-	    (is_function_allowed(F_CLOSE,NULL,fw,True,False) ||
-	     is_function_allowed(F_DELETE,NULL,fw,True,False) ||
-	     is_function_allowed(F_DESTROY,NULL,fw,True,False)))
+	if (
+		IS_UNCLOSABLE(mask) &&
+		mask->flag_mask.common.s.is_unclosable &&
+		(is_function_allowed(
+			 F_CLOSE, NULL, fw, RQORIG_PROGRAM_US,False) ||
+		 is_function_allowed(
+			 F_DELETE, NULL, fw, RQORIG_PROGRAM_US,False) ||
+	     is_function_allowed(
+		     F_DESTROY, NULL, fw, RQORIG_PROGRAM_US, False)))
 	{
 	        return False;
 	}
-	if (!IS_UNCLOSABLE(mask) &&
-	    mask->flag_mask.common.s.is_unclosable &&
-	    (!is_function_allowed(F_CLOSE,NULL,fw,True,False) &&
-	     !is_function_allowed(F_DELETE,NULL,fw,True,False) &&
-	     !is_function_allowed(F_DESTROY,NULL,fw,True,False)))
+	if (
+		!IS_UNCLOSABLE(mask) &&
+		mask->flag_mask.common.s.is_unclosable &&
+		(!is_function_allowed(
+			 F_CLOSE, NULL, fw, RQORIG_PROGRAM_US,False) &&
+		 !is_function_allowed(
+			 F_DELETE, NULL, fw, RQORIG_PROGRAM_US,False) &&
+		 !is_function_allowed(
+			 F_DESTROY, NULL, fw, RQORIG_PROGRAM_US,False)))
 	{
 	        return False;
 	}
@@ -1846,7 +1869,7 @@ static int ver (char *str)
 	return v;
 }
 
-/* match_version() - compare $version against this version of FVWM
+/* match_version() - compare $version against this version of fvwm
  * using the operator specified by $operator. */
 static Bool match_version(char *version, char *operator)
 {
