@@ -234,6 +234,10 @@ typedef struct
 		unsigned has_no_icon_title : 1;
 		unsigned has_override_size : 1;
 		unsigned has_stippled_title : 1;
+		unsigned has_stippled_icon_title : 1;
+		/* default has to be 0, therefore no_, not in macros */
+		unsigned has_no_sticky_stippled_title : 1;
+		unsigned has_no_sticky_stippled_icon_title : 1;
 		unsigned icon_override : 2;
 #define NO_ACTIVE_ICON_OVERRIDE 0
 #define ICON_OVERRIDE           1
@@ -242,10 +246,10 @@ typedef struct
 		unsigned is_bottom_title_rotated : 1;
 		unsigned is_fixed : 1;
 		unsigned is_fixed_ppos : 1;
-	        unsigned is_uniconifiable : 1;
-	        unsigned is_unmaximizable : 1;
-	        unsigned is_unclosable : 1;
-	        unsigned is_maximize_fixed_size_disallowed : 1;
+		unsigned is_uniconifiable : 1;
+		unsigned is_unmaximizable : 1;
+		unsigned is_unclosable : 1;
+		unsigned is_maximize_fixed_size_disallowed : 1;
 		unsigned is_icon_sticky_across_pages : 1;
 		unsigned is_icon_sticky_across_desks : 1;
 		unsigned is_icon_suppressed : 1;
@@ -464,8 +468,26 @@ typedef struct WindowConditionMask
 	int placed_by_button_set_mask;
 } WindowConditionMask;
 
+typedef struct pl_penalty_struct
+{
+	float normal;
+	float ontop;
+	float icon;
+	float sticky;
+	float below;
+	float strut;
+} pl_penalty_struct;
+
+typedef struct pl_percent_penalty_struct
+{
+	int p99;
+	int p95;
+	int p85;
+	int p75;
+} pl_percent_penalty_struct;
+
 /* only style.c and add_window.c are allowed to access this struct! */
-typedef struct
+typedef struct style_flags
 {
 	common_flags_t common;
 	unsigned do_decorate_transient : 1;
@@ -497,8 +519,7 @@ typedef struct
 #define PLACE_TILECASCADE       0x5
 #define PLACE_CASCADE_B         0x6
 #define PLACE_MINOVERLAP        0x7
-#define PLACE_CENTER            0x8
-#define PLACE_UNDERMOUSE        0x9
+#define PLACE_POSITION          0x8
 #define PLACE_MASK              0xF
 	unsigned placement_mode : 4;
 	unsigned ewmh_placement_mode : 2; /* see ewmh.h */
@@ -510,6 +531,8 @@ typedef struct
 	unsigned do_save_under : 1;
 	unsigned do_start_iconic : 1;
 	unsigned do_start_lowered : 1;
+ 	unsigned do_start_shaded : 1;
+ 	unsigned start_shaded_dir : 3;
 	unsigned has_border_width : 1;
 	unsigned has_color_back : 1;
 	unsigned has_color_fore : 1;
@@ -520,6 +543,7 @@ typedef struct
 	unsigned has_icon : 1;
 	unsigned has_icon_boxes : 1;
 	unsigned has_icon_size_limits : 1;
+	unsigned has_min_window_size : 1;
 	unsigned has_max_window_size : 1;
 	unsigned has_icon_background_padding : 1;
 	unsigned has_icon_background_relief : 1;
@@ -558,13 +582,15 @@ typedef struct
 	unsigned use_start_on_page_for_transient : 1;
 	unsigned use_start_on_screen : 1;
 	unsigned manual_placement_honors_starts_on_page : 1;
+	unsigned um_placement_honors_starts_on_page : 1;
 	unsigned capture_honors_starts_on_page : 1;
 	unsigned recapture_honors_starts_on_page : 1;
 	unsigned has_placement_penalty : 1;
 	unsigned has_placement_percentage_penalty : 1;
+	unsigned has_placement_position_string : 1;
 } style_flags;
 
-typedef struct
+typedef struct style_id_t
 {
 	char *name;
 	XID window_id;
@@ -601,8 +627,8 @@ typedef struct window_style
 #define ICON_RESIZE_TYPE_MASK      0x3
 	unsigned icon_resize_type : 2;
 	unsigned char icon_background_padding;
-	char icon_background_relief;
-	char icon_title_relief;
+	signed char icon_background_relief;
+	signed char icon_title_relief;
 	char *icon_font;
 	char *window_font;
 	char *fore_color_name;
@@ -624,13 +650,16 @@ typedef struct window_style
 	int start_page_x;
 	int start_page_y;
 	int start_screen;
+	int min_window_width;
+	int min_window_height;
 	int max_window_width;
 	int max_window_height;
 	int shade_anim_steps;
 	icon_boxes *icon_boxes;
 	float norm_placement_penalty;
-	float placement_penalty[6];
-	int placement_percentage_penalty[4];
+	pl_penalty_struct pl_penalty;
+	pl_percent_penalty_struct pl_percent_penalty;
+	char *pl_position_string;
 	style_flags flags;
 	style_flags flag_default;
 	style_flags flag_mask;
@@ -638,6 +667,21 @@ typedef struct window_style
 	unsigned has_style_changed : 1;
 } window_style;
 
+typedef struct window_g
+{
+	rectangle frame;
+	/* absolute geometry when not maximized */
+	rectangle normal;
+	/* maximized window geometry */
+	rectangle max;
+	/* defect between maximized geometry before and after
+	 * constraining size. */
+	size_rect max_defect;
+	/* original delta between normalized and maximized window,
+	 * used to keep unmaximized window at same screen position */
+	position max_offset;
+} window_g;
+
 /* for each window that is on the display, one of these structures
  * is allocated and linked into a list
  */
@@ -743,7 +787,7 @@ typedef struct FvwmWindow
 	/* pixmap for the icon mask */
 	Pixmap icon_maskPixmap;
 	Pixmap icon_alphaPixmap;
-	unsigned int icon_nalloc_pixels;
+	int icon_nalloc_pixels;
 	Pixel *icon_alloc_pixels;
 	int icon_no_limit;
 	FlocaleFont *icon_font;
@@ -761,6 +805,11 @@ typedef struct FvwmWindow
 	} attr_backup;
 	/* normal hints */
 	XSizeHints hints;
+	struct
+	{
+		int width_inc;
+		int height_inc;
+	} orig_hints;
 	/* WM hints */
 	XWMHints *wmhints;
 	XClassHint class;
@@ -778,17 +827,7 @@ typedef struct FvwmWindow
 	FvwmPicture *mini_icon;
 	char *icon_bitmap_file;
 
-	rectangle frame_g;
-	/* absolute geometry when not maximized */
-	rectangle normal_g;
-	/* maximized window geometry */
-	rectangle max_g;
-	/* defect between maximized geometry before and after constraining
-	 * size. */
-	size_rect max_g_defect;
-	/* original delta between normalized and maximized window, used to
-	 * keep unmaximized window at same screen position */
-	position max_offset;
+	struct window_g g;
 	long *mwm_hints;
 	int ol_hints;
 	int functions;
@@ -829,6 +868,8 @@ typedef struct FvwmWindow
 	char icon_background_relief;
 	char icon_title_relief;
 
+	int min_window_width;
+	int min_window_height;
 	int max_window_width;
 	int max_window_height;
 	int shade_anim_steps;
@@ -840,10 +881,10 @@ typedef struct FvwmWindow
 #define FM_GLOBALLY_ACTIVE 3
 	unsigned char focus_model;
 
-	float placement_penalty[6];
-	int placement_percentage_penalty[4];
+	pl_penalty_struct pl_penalty;
+	pl_percent_penalty_struct pl_percent_penalty;
 
-        unsigned char placed_by_button;
+	unsigned char placed_by_button;
 
 #define EWMH_WINDOW_TYPE_NONE_ID      0
 #define EWMH_WINDOW_TYPE_DESKTOP_ID   1
