@@ -11,6 +11,8 @@
 	((sf)->do_save_under)
 #define SDO_START_LOWERED(sf) \
 	((sf)->do_start_lowered)
+#define SDO_START_SHADED(sf) \
+	((sf)->do_start_shaded)
 #define SHAS_BORDER_WIDTH(sf) \
 	((sf)->has_border_width)
 #define SHAS_COLOR_BACK(sf) \
@@ -31,6 +33,8 @@
 	((sf)->has_icon_background_relief)
 #define SHAS_ICON_TITLE_RELIEF(sf) \
 	((sf)->has_icon_title_relief)
+#define SHAS_MIN_WINDOW_SIZE(sf) \
+	((sf)->has_min_window_size)
 #define SHAS_MAX_WINDOW_SIZE(sf) \
 	((sf)->has_max_window_size)
 #define SHAS_WINDOW_SHADE_STEPS(sf) \
@@ -99,6 +103,8 @@
 	((sf)->has_placement_penalty)
 #define SHAS_PLACEMENT_PERCENTAGE_PENALTY(sf) \
 	((sf)->has_placement_percentage_penalty)
+#define SHAS_PLACEMENT_POSITION_STRING(sf) \
+	((sf)->has_placement_position_string
 #define SCR_MOTION_METHOD(sf) \
 	((sf)->ws_cr_motion_method)
 
@@ -505,6 +511,10 @@
 	((s).start_screen)
 #define SSET_START_SCREEN(s,x) \
 	((s).start_screen = (x))
+#define SSET_STARTS_SHADED_DIR(s,x) \
+	((s).flags.start_shaded_dir = (x))
+#define SGET_STARTS_SHADED_DIR(s)		\
+	((s).flags.start_shaded_dir)
 #define SGET_MIN_ICON_WIDTH(s) \
 	((s).min_icon_width)
 #define SSET_MIN_ICON_WIDTH(s,x) \
@@ -537,10 +547,18 @@
 	((s).icon_title_relief)
 #define SSET_ICON_TITLE_RELIEF(s,x) \
 	((s).icon_title_relief = (x))
+#define SGET_MIN_WINDOW_WIDTH(s) \
+	((s).min_window_width)
+#define SSET_MIN_WINDOW_WIDTH(s,x) \
+	((s).min_window_width = (x))
 #define SGET_MAX_WINDOW_WIDTH(s) \
 	((s).max_window_width)
 #define SSET_MAX_WINDOW_WIDTH(s,x) \
 	((s).max_window_width = (x))
+#define SGET_MIN_WINDOW_HEIGHT(s) \
+	((s).min_window_height)
+#define SSET_MIN_WINDOW_HEIGHT(s,x) \
+	((s).min_window_height = (x))
 #define SGET_MAX_WINDOW_HEIGHT(s) \
 	((s).max_window_height)
 #define SSET_MAX_WINDOW_HEIGHT(s,x) \
@@ -553,46 +571,54 @@
 	((s).icon_boxes)
 #define SSET_ICON_BOXES(s,x) \
 	((s).icon_boxes = (x))
+#define SGET_PLACEMENT_PENALTY_PTR(s) \
+	(&(s).pl_penalty)
 #define SGET_NORMAL_PLACEMENT_PENALTY(s) \
-	((s).placement_penalty[0])
+	((s).pl_penalty.normal)
 #define SGET_ONTOP_PLACEMENT_PENALTY(s) \
-	((s).placement_penalty[1])
+	((s).pl_penalty.ontop)
 #define SGET_ICON_PLACEMENT_PENALTY(s) \
-	((s).placement_penalty[2])
+	((s).pl_penalty.icon)
 #define SGET_STICKY_PLACEMENT_PENALTY(s) \
-	((s).placement_penalty[3])
+	((s).pl_penalty.sticky)
 #define SGET_BELOW_PLACEMENT_PENALTY(s) \
-	((s).placement_penalty[4])
+	((s).pl_penalty.below)
 #define SGET_EWMH_STRUT_PLACEMENT_PENALTY(s) \
-	((s).placement_penalty[5])
+	((s).pl_penalty.strut)
 #define SSET_NORMAL_PLACEMENT_PENALTY(s,x) \
-	((s).placement_penalty[0] = (x))
+	((s).pl_penalty.normal = (x))
 #define SSET_ONTOP_PLACEMENT_PENALTY(s,x) \
-	((s).placement_penalty[1] = (x))
+	((s).pl_penalty.ontop = (x))
 #define SSET_ICON_PLACEMENT_PENALTY(s,x) \
-	((s).placement_penalty[2] = (x))
+	((s).pl_penalty.icon = (x))
 #define SSET_STICKY_PLACEMENT_PENALTY(s,x) \
-	((s).placement_penalty[3] = (x))
+	((s).pl_penalty.sticky = (x))
 #define SSET_BELOW_PLACEMENT_PENALTY(s,x) \
-	((s).placement_penalty[4] = (x))
+	((s).pl_penalty.below = (x))
 #define SSET_EWMH_STRUT_PLACEMENT_PENALTY(s,x) \
-	((s).placement_penalty[5] = (x))
+	((s).pl_penalty.strut = (x))
+#define SGET_PLACEMENT_PERCENTAGE_PENALTY_PTR(s) \
+	(&(s).pl_percent_penalty)
 #define SGET_99_PLACEMENT_PERCENTAGE_PENALTY(s) \
-	((s).placement_percentage_penalty[0])
+	((s).pl_percent_penalty.p99)
 #define SGET_95_PLACEMENT_PERCENTAGE_PENALTY(s) \
-	((s).placement_percentage_penalty[1])
+	((s).pl_percent_penalty.p95)
 #define SGET_85_PLACEMENT_PERCENTAGE_PENALTY(s) \
-	((s).placement_percentage_penalty[2])
+	((s).pl_percent_penalty.p85)
 #define SGET_75_PLACEMENT_PERCENTAGE_PENALTY(s) \
-	((s).placement_percentage_penalty[3])
+	((s).pl_percent_penalty.p75)
 #define SSET_99_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-	((s).placement_percentage_penalty[0] = (x))
+	((s).pl_percent_penalty.p99 = (x))
 #define SSET_95_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-	((s).placement_percentage_penalty[1] = (x))
+	((s).pl_percent_penalty.p95 = (x))
 #define SSET_85_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-	((s).placement_percentage_penalty[2] = (x))
+	((s).pl_percent_penalty.p85 = (x))
 #define SSET_75_PLACEMENT_PERCENTAGE_PENALTY(s,x) \
-	((s).placement_percentage_penalty[3] = (x))
+	((s).pl_percent_penalty.p75 = (x))
+#define SGET_PLACEMENT_POSITION_STRING(s) \
+	((s).pl_position_string)
+#define SSET_PLACEMENT_POSITION_STRING(s,x)	\
+	((s).pl_position_string = (x))
 
 /* function prototypes */
 void lookup_style(FvwmWindow *fw, window_style *styles);
